@@ -208,7 +208,7 @@ def get_host():
 def get_lang():
     lang = "en"
     host = get_host()
-    if host and '.' in host:
+    if host and "." in host:
         lang = host.split(".")[0]
     return lang
 
@@ -225,6 +225,8 @@ def get_domain():
 
 
 def get_scheme():
+    if os.environ.get("FORCE_HTTPS"):
+        return "https"
     return cherrypy.request.scheme
 
 
@@ -280,6 +282,9 @@ def load_app_modules(app_directory):
     spec.loader.exec_module(lib_load_module)
     setattr(this, "lib", lib_load_module)
 
+    libdir = join(app_directory, "lib")
+    sys.path.append(libdir)
+
     for filename in glob(libglob):
         print("** Loading library", filename)
         module_name = splitext(basename(filename))[0]
@@ -289,6 +294,7 @@ def load_app_modules(app_directory):
         setattr(lib_load_module, module_name, load_module)
         cherrypy.engine.autoreload.files.add(filename)
 
+    sys.path.remove(libdir)
 
 def render(name, lang=None, **kwargs):
     if not lang:
