@@ -4,6 +4,7 @@
 import yaml
 import re
 
+from os import environ
 from os.path import basename, dirname, join, exists, getmtime, splitext
 from jinja2 import TemplateNotFound, Environment, select_autoescape, meta
 from jinja2 import BaseLoader, Markup, escape
@@ -26,6 +27,7 @@ class Feature(object):
 
     def on_content_directory_set(self, content_directory):
         self._template_engine = TemplateEngine(content_directory)
+        controller._template_engine = self._template_engine
 
     def on_found_content_file(self, content_root, content_name):
         """ A file was found """
@@ -104,6 +106,7 @@ class TemplateEngine:
                     yaml_data = yaml.safe_load(yaml_renderer.render())
                     yaml_variables.update(dict(yaml_data))
                     break
+        yaml_variables["env"] = environ
         yaml_variables.update(**kwargs)
 
         return template.render(**yaml_variables)
