@@ -38,28 +38,36 @@ def setup_app(app_name, app_directory, no_logs):
 
 
 def load_tools(app_directory):
-    tools_glob = join(app_directory, "tools", "*.py")
+    tools_dir = join(app_directory, "tools")
+    tools_glob = join(tools_dir, "*.py")
     for tool_filename in glob(tools_glob):
         tool_name = basename(tool_filename).split(".")[0]
         print(f"** Loading tool {tool_filename}")
-        spec = importlib.util.spec_from_file_location("tools_"+tool_name, tool_filename)
+        spec = importlib.util.spec_from_file_location(
+            "tools_" + tool_name, tool_filename
+        )
         tool = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(tool)
-        app_config = {
-            f"tools.{tool_name}.on": True
-        }
+        app_config = {f"tools.{tool_name}.on": True}
         cherrypy.config.update(app_config)
+        cherrypy.engine.autoreload.files.add(tool_filename)
+    cherrypy.engine.autoreload.files.add(tools_dir)
 
 
 def run_boot(app_directory):
-    boot_log = join(app_directory, "boot", "*.py")
+    boot_dir = join(app_directory, "boot")
+    boot_log = join(boot_dir, "*.py")
     for boot_filename in glob(boot_log):
         boot_name = basename(boot_filename).split(".")[0]
         print(f"** Running boot script {boot_filename}")
-        spec = importlib.util.spec_from_file_location("boot_"+boot_name, boot_filename)
+        spec = importlib.util.spec_from_file_location(
+            "boot_" + boot_name, boot_filename
+        )
         boot_module = importlib.util.module_from_spec(spec)
         spec.loader.exec_module(boot_module)
         boot_module.start()
+        cherrypy.engine.autoreload.files.add(boot_filename)
+    cherrypy.engine.autoreload.files.add(boot_dir)
 
 
 def setup_features():
@@ -114,7 +122,6 @@ def set_engine_config(test_mode, no_logs):
         "tools.encode.encoding": "utf-8",
         "tools.encode.errors": "replace",
         "tools.trailing_slash.on": False,
-        "tools.sessions.on": True,
         "checker.on": False,
     }
 
@@ -132,15 +139,5 @@ def set_engine_config(test_mode, no_logs):
         app_config.update(
             {"log.screen": False, "log.access_file": None, "log.error_file": None}
         )
-    cors_domain = environ.get("CORS_DOMAIN")
-    if cors_domain:
-        app_config.update(
-            {
-                "tools.response_headers.on": True,
-                "tools.response_headers.headers": [
-                    ("Access-Control-Allow-Origin", cors_domain)
-                ],
-            }
-        )
 
     cherrypy.config.update(app_config)
